"""tasks.py"""

from invoke import task

from blue_chip import constants


@task
def clean(ctx, docs=False, bytecode=False, lintrc=False, extra=""):
    """Cleanup"""
    patterns = ["build"]
    if docs:
        patterns.append("docs/_build")
    if bytecode:
        patterns.append("**/*.pyc")
    if lintrc:
        patterns.append("/".join(constants.BC_LINTRC_PATH.parts[-2:]))
    if extra:
        patterns.append(extra)
    for pattern in patterns:
        print(f"cleaning {pattern}...")
        ctx.run(f"rm -rf {pattern}")



"""tests/test_basic.py"""
import importlib
import pathlib
import subprocess

import pytest
from setuptools import find_packages

ROOT = pathlib.Path(__file__).joinpath("..").resolve()


def test_for_fire():
    all_modules = find_packages(exclude=["tests"])
    on_fire = {}

    for module in all_modules:
        try:
            importlib.import_module(module)
            print(f"✔️  {module}")
        except ImportError as import_error:
            on_fire[module] = import_error
            print(f"❌  {module}")
        except Exception as error:
            on_fire[module] = error
            print(f"❌  {module}")

    if on_fire:
        raise ImportError(", ".join(on_fire.keys()))


@pytest.mark.parametrize("cmd", ["fmt", "lint", "sort"])
def test_noarg_cli_task(cmd):
    cmplt_process = subprocess.run(["bcp", cmd])
    print(cmplt_process.stdout)
    assert cmplt_process.returncode is 0


@pytest.mark.parametrize(
    "targets_arg",
    ["foo.py", ("foo.py", "bar.py"), ["foo.py", "bar.py"], {"foo.py", "bar.py"}],
)
def test_fmt_cmd(targets_arg):
    from blue_chip.tasks.formatting import _fmt_cmd

    cmd_string = _fmt_cmd(88, targets_arg)
    assert isinstance(cmd_string, str)


if __name__ == "__main__":
    print(ROOT)
    pytest.main(args=[__file__, "-v"])



#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['blue_chip', 'blue_chip.config', 'blue_chip.tasks']

package_data = \
{'': ['*'], 'blue_chip': ['lintrc/*']}

install_requires = \
['black', 'invoke', 'prospector[with_pyroma]']

entry_points = \
{'console_scripts': ['bc = blue_chip.__main__:program.run',
                     'bcp = blue_chip.__main__:program.run']}

setup(name='blue-chip',
      version='0.0.4',
      description='blue_chip',
      author='Gabriel Gore',
      author_email='gabriel59kg@gmail.com',
      url='https://github.com/Kilo59/blue-chip',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      entry_points=entry_points,
      python_requires='>=3.6',
     )
